@@ -1,6 +1,7 @@
-/*****************************************************************************
+/**
  *
- * Author:  Peter Leese <hubbe@hubbe.net>
+ * This file is part of mozplugger a fork of plugger, for list of developers
+ * see the README file.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  *
- *****************************************************************************/
+ */
 
 #ifndef _MOZPLUGGER_CHILD_
 #define _MOZPLUGGER_CHILD_
@@ -25,12 +26,22 @@ extern void restore_SIGCHLD_to_default(void);
 
 /* Use this to redirct the SIGCHLD signal to a file descriptor so we can
  * select on this signal */
-extern void redirect_SIGCHLD_to_fd(void);     
+extern int redirect_SIGCHLD_to_fd(void);
 
-extern int  get_SIGCHLD_fd(void);
+extern int get_SIGCHLD_fd(void);
 
 extern void handle_SIGCHLD_event(void);
 
-extern pid_t spawn_app(char * command, const int flags, const int maxOpenFd);
+
+extern int get_chld_out_fd(void);
+
+extern void handle_chld_out_event(int fd);
+
+
+extern pid_t spawn_app(char * command, const int flags);
+
+extern int wait_child(pid_t pid);
+
+extern void kill_app(pid_t pid);
 
 #endif
